@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2014 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -25,16 +25,17 @@
 #include "catalog_private.h"
 #include "catalogstorage.h"
 #include "cmd.h"
-#include <kdebug.h>
+#include <kdemacros.h>
 #include <klocalizedstring.h>
 #include <QMultiHash>
 #include <QtAlgorithms>
-
+#include <QDebug>
 
 
 MergeCatalog::MergeCatalog(QObject* parent, Catalog* baseCatalog, bool saveChanges)
  : Catalog(parent)
  , m_baseCatalog(baseCatalog)
+ , m_unmatchedCount(0)
  , m_modified(false)
 {
     setActivePhase(baseCatalog->activePhase(),baseCatalog->activePhaseRole());
@@ -57,7 +58,7 @@ void MergeCatalog::copyFromBaseCatalog(const DocPosition& pos, int options)
 
         //note the explicit use of map...
         if (m_storage->isApproved(ourPos)!=m_baseCatalog->isApproved(pos))
-            //kWarning()<<ourPos.entry<<"SHIT";
+            //qWarning()<<ourPos.entry<<"SHIT";
             m_storage->setApproved(ourPos, m_baseCatalog->isApproved(pos));
         DocPos p(pos);
         if (!m_originalHashes.contains(p))
@@ -100,14 +101,14 @@ bool MergeCatalog::isPlural(uint index) const
     //sanity
     if (m_map.at(index) == -1)
     {
-         kWarning()<<"!!! index"<<index<<"m_map.at(index)"<<m_map.at(index)<<"numberOfEntries()"<<numberOfEntries();
+         qWarning()<<"!!! index"<<index<<"m_map.at(index)"<<m_map.at(index)<<"numberOfEntries()"<<numberOfEntries();
          return false;
     }
 
     return Catalog::isPlural(m_map.at(index));
 }
 
-bool MergeCatalog::isPresent(const short int& entry) const
+bool MergeCatalog::isPresent(const int& entry) const
 {
     return m_map.at(entry)!=-1;
 }
@@ -160,9 +161,9 @@ static QString strip(QString source)
     return source;
 }
 
-int MergeCatalog::loadFromUrl(const KUrl& url)
+int MergeCatalog::loadFromUrl(const QString& filePath)
 {
-    int errorLine=Catalog::loadFromUrl(url);
+    int errorLine=Catalog::loadFromUrl(filePath);
     if (KDE_ISUNLIKELY( errorLine!=0 ))
         return errorLine;
 
@@ -192,6 +193,7 @@ int MergeCatalog::loadFromUrl(const KUrl& url)
         QString key=strip(baseStorage.source(i));
         const QList<int>& entries=mergeMap.values(key);
         QList<MatchItem> scores;
+
         int k=entries.size();
         if (k)
         {
@@ -207,7 +209,7 @@ int MergeCatalog::loadFromUrl(const KUrl& url)
                 m_mergeDiffIndex.append(i.entry);
 
         }
-        ++i.entry;
+        ++(i.entry);
     }
 
 
@@ -237,7 +239,7 @@ int MergeCatalog::loadFromUrl(const KUrl& url)
 /*    QMultiHash<QString, int>::iterator it = mergeMap.begin();
     while (it != mergeMap.end())
     {
-        //kWarning()<<it.value()<<it.key();
+        //qWarning()<<it.value()<<it.key();
         ++it;
     }*/
     m_unmatchedCount=numberOfEntries()-mergePositions.count();
@@ -345,4 +347,3 @@ void MergeCatalog::copyToBaseCatalog(int options)
     }
 }
 
-#include "mergecatalog.moc"
